#PBS -l nodes=2:ppn=16:xeon16
#PBS -l walltime=0:25:0
#PBS -o stdout.log
#PBS -e stderr.log

from ase.io import read
from gpaw import GPAW, PoissonSolver, Mixer, FermiDirac, LCAO
from gpaw.utilities import h2gpts
from gpaw.utilities.timing import ParallelTimer

system = read('blasphemous_monstrosity.xyz')
system.rattle(stdev=0.05)
system.center(vacuum=6.0)

calc = GPAW(mode=LCAO(atomic_hamiltonian='distributed'),
            basis='szp(dzp)',
            #basis={None: 'sz(dzp)', 'Au': 'dzp'},
            #basis={None: 'dzp', 'C': 'szp(dzp)', 'H': 'sz(dzp)'},
            gpts=h2gpts(0.25, system.get_cell(), idiv=32),
            parallel=dict(order='kdb',
                          sl_default=(4, 8, 64),
                          band=1),
            timer=ParallelTimer(),
            mixer=Mixer(0.1, 7, 50.0),
            nbands=int(1.05 * 6354 / 2.0),
            occupations=FermiDirac(0.01),
            txt='gpaw.blasphemous_monstrosity.txt',
            poissonsolver=PoissonSolver(relax='GS'))

def stopcalc():
    calc.scf.converged = True
calc.attach(stopcalc, 3)

system.set_calculator(calc)
system.get_potential_energy()
